import { Pagination, PaginationContent, PaginationItem, PaginationLink, PaginationNext, PaginationPrevious } from "@/components/ui/pagination";
import { useTranslations } from "next-intl";
import { useEffect } from "react";

const ProductPagination = ({ currentPage, totalPages, handlePageChange }: { currentPage: number, totalPages: number, handlePageChange: (page: number) => void }) => {
	const t = useTranslations();

	// Ensure we have valid values
	const safeCurrentPage = Math.max(1, Math.min(currentPage, totalPages));
	const safeTotalPages = Math.max(1, totalPages);

	// Debug effect to log when props change
	useEffect(() => {
		console.log("ProductPagination props updated - currentPage:", currentPage, "totalPages:", totalPages);
	}, [currentPage, totalPages]);

	return (
		<div className="mt-8 flex justify-center">
			<Pagination>
				<PaginationContent>
					{/* Previous Button */}
					<PaginationItem>
						<PaginationPrevious
							href="#"
							onClick={(e) => {
								e.preventDefault();
								console.log("Previous button clicked, current page:", safeCurrentPage);
								if (safeCurrentPage > 1) {
									handlePageChange(safeCurrentPage - 1);
								}
							}}
							aria-disabled={safeCurrentPage === 1}
							className={safeCurrentPage === 1 ? "pointer-events-none opacity-50" : ""}
							aria-label={t("Previous")}
						>
							{t("Previous")}
						</PaginationPrevious>
					</PaginationItem>

					{/* Page Number Links with Ellipsis */}
					{(() => {
						const pages = [];
						const maxVisiblePages = 2;

						// Always show first page
						pages.push(
							<PaginationItem key={1}>
								<PaginationLink
									href="#"
									onClick={(e) => {
										e.preventDefault();
										console.log("Page 1 clicked");
										handlePageChange(1);
									}}
									isActive={safeCurrentPage === 1}
									aria-current={safeCurrentPage === 1 ? "page" : undefined}
									className={safeCurrentPage === 1 ? "bg-custom-primary-accent text-white" : ""}
								>
									1
								</PaginationLink>
							</PaginationItem>
						);

						// Calculate range of pages to show
						let startPage = Math.max(2, safeCurrentPage - Math.floor(maxVisiblePages / 2));
						const endPage = Math.min(safeTotalPages - 1, startPage + maxVisiblePages - 1);

						// Adjust if we're near the end
						if (endPage - startPage < maxVisiblePages - 1) {
							startPage = Math.max(2, endPage - (maxVisiblePages - 1));
						}

						// Add ellipsis after first page if needed
						if (startPage > 2) {
							pages.push(
								<PaginationItem key="ellipsis1">
									<span className="px-4 py-2">...</span>
								</PaginationItem>
							);
						}

						// Add middle pages
						for (let i = startPage; i <= endPage; i++) {
							pages.push(
								<PaginationItem key={i}>
									<PaginationLink
										href="#"
										onClick={(e) => {
											e.preventDefault();
											console.log(`Page ${i} clicked`);
											handlePageChange(i);
										}}
										isActive={safeCurrentPage === i}
										aria-current={safeCurrentPage === i ? "page" : undefined}
										className={safeCurrentPage === i ? "bg-custom-primary-accent text-white" : ""}
									>
										{i}
									</PaginationLink>
								</PaginationItem>
							);
						}

						// Add ellipsis before last page if needed
						if (endPage < safeTotalPages - 1) {
							pages.push(
								<PaginationItem key="ellipsis2">
									<span className="px-4 py-2">...</span>
								</PaginationItem>
							);
						}

						// Always show last page if there's more than one page
						if (safeTotalPages > 1) {
							pages.push(
								<PaginationItem key={safeTotalPages}>
									<PaginationLink
										href="#"
										onClick={(e) => {
											e.preventDefault();
											console.log(`Last page ${safeTotalPages} clicked`);
											handlePageChange(safeTotalPages);
										}}
										isActive={safeCurrentPage === safeTotalPages}
										aria-current={safeCurrentPage === safeTotalPages ? "page" : undefined}
										className={safeCurrentPage === safeTotalPages ? "bg-custom-primary-accent text-white" : ""}
									>
										{safeTotalPages}
									</PaginationLink>
								</PaginationItem>
							);
						}

						return pages;
					})()}

					{/* Next Button */}
					<PaginationItem>
						<PaginationNext
							href="#"
							onClick={(e) => {
								e.preventDefault();
								console.log("Next button clicked, current page:", safeCurrentPage);
								if (safeCurrentPage < safeTotalPages) {
									handlePageChange(safeCurrentPage + 1);
								}
							}}
							aria-disabled={safeCurrentPage === safeTotalPages}
							className={safeCurrentPage === safeTotalPages ? "pointer-events-none opacity-50" : ""}
							aria-label={t("Next")}
						>
							{t("Next")}
						</PaginationNext>
					</PaginationItem>
				</PaginationContent>
			</Pagination>
		</div>
	);
};

export default ProductPagination;
